package com.goldenwater.slaj.eutr.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.goldenwater.slaj.eutr.mapper.BisEutrCourToEqMapper;
import com.goldenwater.slaj.eutr.domain.BisEutrCourToEq;
import com.goldenwater.slaj.eutr.service.IBisEutrCourToEqService;

@Service
public class BisEutrCourToEqServiceImpl implements IBisEutrCourToEqService {
    @Autowired
    private BisEutrCourToEqMapper bisEutrCourToEqMapper;

    @Override
    public BisEutrCourToEq selectBisEutrCourToEqByGuid(String guid) {
        return bisEutrCourToEqMapper.selectBisEutrCourToEqByGuid(guid);
    }

    @Override
    public List<BisEutrCourToEq> selectBisEutrCourToEqList(BisEutrCourToEq bisEutrCourToEq) {
        return bisEutrCourToEqMapper.selectBisEutrCourToEqList(bisEutrCourToEq);
    }

    @Override
    public int insertBisEutrCourToEq(BisEutrCourToEq bisEutrCourToEq) {
        return bisEutrCourToEqMapper.insertBisEutrCourToEq(bisEutrCourToEq);
    }

    @Override
    public int updateBisEutrCourToEq(BisEutrCourToEq bisEutrCourToEq) {
        return bisEutrCourToEqMapper.updateBisEutrCourToEq(bisEutrCourToEq);
    }

    @Override
    public int deleteBisEutrCourToEqByGuid(String guid) {
        return bisEutrCourToEqMapper.deleteBisEutrCourToEqByGuid(guid);
    }

    @Override
    public int deleteBisEutrCourToEqByGuids(String[] guids) {
        return bisEutrCourToEqMapper.deleteBisEutrCourToEqByGuids(guids);
    }
}
